.. _dev-index:


Development notes
=================

This section contains information on building and installing PyEDFlib
from source code as well as instructions for preparing the build environment
on Windows and Linux.

.. toctree::
   :maxdepth: 2

   preparing_windows_build_environment
   preparing_linux_build_environment
   installing_build_dependencies
   building_extension
   testing
   how_to_release

Something not working?
----------------------

If these instructions are not clear or you need help setting up your
development environment, go ahead and  open a ticket on GitHub_.

.. _GitHub: https://github.com/holgern/pyedflib